@@ -4,19 +4,21 @@ use anyhow::Context;
 use lsp_server::Connection;
 use ruff_db::system::{OsSystem, SystemPathBuf};
 
-use crate::server::Server;
+use crate::db::Db;
+pub use crate::logging::{LogLevel, init_logging};
+pub use crate::server::{PartialWorkspaceProgress, PartialWorkspaceProgressParams, Server};
+pub use crate::session::{ClientOptions, DiagnosticMode, GlobalOptions, WorkspaceOptions};
 pub use document::{NotebookDocument, PositionEncoding, TextDocument};
-pub(crate) use session::{DocumentQuery, Session};
+pub(crate) use session::Session;
 
+mod capabilities;
+mod db;
 mod document;
 mod logging;
 mod server;
 mod session;
 mod system;
 
-#[cfg(test)]
-pub mod test;
-
 pub(crate) const SERVER_NAME: &str = "ty";
 pub(crate) const DIAGNOSTIC_NAME: &str = "ty";
 
@@ -25,6 +27,7 @@ pub(crate) const DIAGNOSTIC_NAME: &str = "ty";
 pub(crate) type Result<T> = anyhow::Result<T>;
 
 pub fn run_server() -> anyhow::Result<()> {
+    let _ = print_interactive_warning();
     let four = NonZeroUsize::new(4).unwrap();
 
     // by default, we set the number of worker threads to `num_cpus`, with a maximum of 4.
@@ -48,7 +51,7 @@ pub fn run_server() -> anyhow::Result<()> {
     // This is to complement the `LSPSystem` if the document is not available in the index.
     let fallback_system = Arc::new(OsSystem::new(cwd));
 
-    let server_result = Server::new(worker_threads, connection, fallback_system, true)
+    let server_result = Server::new(worker_threads, connection, fallback_system, false)
         .context("Failed to start server")?
         .run();
 
@@ -69,3 +72,20 @@ pub fn run_server() -> anyhow::Result<()> {
 
     result
 }
+
+fn print_interactive_warning() -> std::io::Result<()> {
+    use std::io::{IsTerminal, Write};
+
+    if std::io::stdin().is_terminal() {
+        let mut stderr = std::io::stderr().lock();
+        writeln!(
+            stderr,
+            "WARNING: the ty LSP server should not be run interactively"
+        )?;
+        writeln!(
+            stderr,
+            "See https://docs.astral.sh/ty/editors/ for how to configure your editor"
+        )?;
+    }
+    Ok(())
+}
